# mq-fw

#### 介绍
消息队列的框架，包含pulsar和 rabbitmq。

#### 功能
1. pulsar 订阅和消费
2. rabbitmq 订阅和消费
3. pulsar与rabbitmq 互相订阅和消费


#### 安装教程

pip install mq-fw

#### 使用说明

1.  使用 pulsar框架

        import pulsar_mq

2.  使用 rabbitmq框架

        import pulsar_mq

3.  使用 mq框架

        import mq
        
        
#### 详细的使用说明，后续补充

